Crate datafusion_python_util

Crate datafusion_python_util 

Re-exports

pub use crate::errors::to_datafusion_err;

Modules

errors

Macros

from_pycapsule
Define a <fn_name>(obj) -> PyResult<Arc<$output_type>> extractor that accepts either a raw PyCapsule carrying $ffi_type or any object exposing __<capsule_name>__() that returns one.
try_from_pycapsule
Same shape as from_pycapsule! but for FFI types whose conversion into Arc<$output_type> is fallible (uses TryFrom).

Functions

create_logical_extension_capsule
create_physical_extension_capsule
ffi_logical_codec_from_pycapsule
get_global_ctx
Utility to get the Global Datafussion CTX
get_tokio_runtime
Utility to get the Tokio Runtime from Python
is_ipython_env
parse_volatility
physical_codec_from_pycapsule
physical_optimizer_rule_from_pycapsule
spawn_future
Spawn a Future on the Tokio runtime and wait for completion while respecting Python signal handling.
table_provider_from_pycapsule
task_context_from_pycapsule
validate_pycapsule
wait_for_future
Utility to collect rust futures with GIL released and respond to Python interrupts such as KeyboardInterrupt. If a signal is received while the future is running, the future is aborted and the corresponding Python exception is raised.