Re-exports
pub use crate::errors::to_datafusion_err;
Modules
Macros
- from_
pycapsule - Define a
<fn_name>(obj) -> PyResult<Arc<$output_type>>extractor that accepts either a rawPyCapsulecarrying$ffi_typeor any object exposing__<capsule_name>__()that returns one. - try_
from_ pycapsule - Same shape as
from_pycapsule!but for FFI types whose conversion intoArc<$output_type>is fallible (usesTryFrom).
Functions
- create_
logical_ extension_ capsule - create_
physical_ extension_ capsule - ffi_
logical_ codec_ from_ pycapsule - get_
global_ ctx - Utility to get the Global Datafussion CTX
- get_
tokio_ runtime - Utility to get the Tokio Runtime from Python
- is_
ipython_ env - parse_
volatility - physical_
codec_ from_ pycapsule - physical_
optimizer_ rule_ from_ pycapsule - spawn_
future - Spawn a
Futureon the Tokio runtime and wait for completion while respecting Python signal handling. - table_
provider_ from_ pycapsule - task_
context_ from_ pycapsule - validate_
pycapsule - wait_
for_ future - Utility to collect rust futures with GIL released and respond to
Python interrupts such as
KeyboardInterrupt. If a signal is received while the future is running, the future is aborted and the corresponding Python exception is raised.