Crate datafusion_python_util

Crate datafusion_python_util 

Modules

errors

Functions

create_logical_extension_capsule
ffi_logical_codec_from_pycapsule
get_global_ctx
Utility to get the Global Datafussion CTX
get_tokio_runtime
Utility to get the Tokio Runtime from Python
is_ipython_env
parse_volatility
spawn_future
Spawn a Future on the Tokio runtime and wait for completion while respecting Python signal handling.
table_provider_from_pycapsule
validate_pycapsule
wait_for_future
Utility to collect rust futures with GIL released and respond to Python interrupts such as KeyboardInterrupt. If a signal is received while the future is running, the future is aborted and the corresponding Python exception is raised.