Modules
Functions
- create_
logical_ extension_ capsule - ffi_
logical_ codec_ from_ pycapsule - get_
global_ ctx - Utility to get the Global Datafussion CTX
- get_
tokio_ runtime - Utility to get the Tokio Runtime from Python
- is_
ipython_ env - parse_
volatility - spawn_
future - Spawn a
Futureon the Tokio runtime and wait for completion while respecting Python signal handling. - table_
provider_ from_ pycapsule - validate_
pycapsule - wait_
for_ future - Utility to collect rust futures with GIL released and respond to
Python interrupts such as
KeyboardInterrupt. If a signal is received while the future is running, the future is aborted and the corresponding Python exception is raised.